# snekspec

Data validator inspired by clojure.spec.

## Project status 

Proof of concept. If you have a suggestion please [file an issue](https://github.com/alexjuda/snekspec/issues/new). If you just like the idea, star the repo. :)
